#!/bin/bash
# -*- mode: shell-script; -*-
# author: Arnaud Chapon

app_name="perform_stats.sh"
printing=0
debug=0

###

title=""

###

function __msg()
{
    echo "${app_name}:" $@ >&2
}

function debug_msg()
{
    test ${debug} -eq 0 && return
    __msg "DEBUG: " "$@"
}

function warning_msg()
{
    __msg "WARNING: " "$@"
}

function info_msg()
{
    __msg "NOTICE: " "$@"
}

function error_msg()
{
    __msg "ERROR: " "$@"
    app_exit 1
}

function app_exit()
{
    exit $1
}

function app_usage()
{
    cat<<EOF
________________________________________________________________________________

${app_name} - Build some basic statistical values on an input file
 
Usage: 
       ${app_name} <OPTIONS> -i <INPUT FILENAME>

Options:

       -h | --help           : print this help
       -d | --debug          : debug mode
       -p | --print          : printing mode for gnuplot

       -t <TITLE>            : specify a title
       -i <INPUT FILENAME>   : specify input filemane

Example:

 ${app_name} -d -i notes.data -t "Controle d'utilisation"

_______________________________________________________________________________

EOF
}

file=""
while [ -n "$1" ]; do    
    arg="$1"
    if [ "${arg:0:1}" = "-" ]; then
        if [ "x${arg}" = "x-h" -o "x${arg}" = "x--help" ]; then
            app_usage
            app_exit 0
        elif [ "x${arg}" = "x-d" -o "x${arg}" = "x--debug" ]; then
            debug=1
        elif [ "x${arg}" = "x-p" -o "x${arg}" = "x--print" ]; then
            printing=1
        elif [ "x${arg}" = "x-t" -o "x${arg}" = "x--title" ]; then
            shift 1
            arg="$1"
            title=${arg}
        elif [ "x${arg}" = "x-i" -o "x${arg}" = "x--infile" ]; then
            shift 1
            arg="$1"
            file=${arg}
        else
            app_usage
            error_msg "Unknown switch '$arg'!"
        fi
    else
        app_usage
        error_msg "Unknown argument '$arg'!"
    fi
    shift 1
done

if [ "x$file" = "x" ]; then
    app_usage
    error_msg "Specify an input file using the '-i' option. Abort!"
fi

if [ ! -f $file ]; then
    error_msg "File '$file' does not exist. Abort!"    
fi

histo=`echo $file | sed -e "s/.data/.his/g"`
less $file | gsl-histogram 0 20 8 > $histo

if [ $printing -ne 0 ]; then

    outdir=`dirname $file`

    cat > macro.gpl <<EOF
# -*- mode: gnuplot; -*-

set term postscript color enhanced
set output "${outdir}/histo.ps"

set xlabel "note"
set ylabel "n"

set grid lt 9 lw 0.3

plot [0:20][*:*] '$histo' u ((\$1+\$2)/2):3 lw 3 with boxes title "$title"

# end
EOF
    

    gnuplot macro.gpl

    ps2pdf ${outdir}/histo.ps ${outdir}/histo.pdf

    cat > ${outdir}/result.tex <<EOF
\documentclass[a4paper,12pt]{report}
\usepackage[utf8]{inputenc} 
\usepackage[french]{babel}
\usepackage[T1]{fontenc}
\usepackage{graphicx}
\usepackage{vmargin}

\setmarginsrb{2truecm}{2.5truecm}{2truecm}{2.5truecm}
  {1.2truecm}{1.5truecm}{1.2truecm}{1.5truecm}

\begin{document}

  \begin{center}
    \section*{$title}
    \vspace{1.5cm}
    \begin{figure}[htbp]
      \includegraphics[width=\linewidth]{${outdir}/histo}
    \end{figure}
  \end{center}

  \vspace{1.5cm}

EOF

    python stat.py -i $file >> ${outdir}/result.tex

    cat >> ${outdir}/result.tex <<EOF

\end{document}
EOF

    current_dir=`pwd`
    cd ${outdir}
    pdflatex ${outdir}/result.tex
    cd ${current_dir}

    rm $histo ${outdir}/result.aux ${outdir}/result.log ${outdir}/result.tex
    rm ${outdir}/histo.ps ${outdir}/histo.pdf
    rm macro.gpl

    if [ "x${title}" = "x" ]; then
	evince ${outdir}/result.pdf &
    else
	new_title=`echo ${title} | sed -e "s/ /_/g" | sed -e "s/'/_/g"`
	mv ${outdir}/result.pdf ${outdir}/${new_title}.pdf
	evince ${outdir}/${new_title}.pdf &
    fi
else
    cat > macro.gpl <<EOF
# -*- mode: gnuplot; -*-

set xlabel "note"
set ylabel "n"

set grid lt 9 lw 0.3

plot [0:20][*:*] '$histo' u ((\$1+\$2)/2):3 lw 3 with boxes title "$title"

pause -1 "hit..."

# end
EOF
    
    python stat.py -i $file
    
    gnuplot macro.gpl
    
    rm $histo
    rm macro.gpl

fi